@@ -11,12 +11,21 @@ set -ev
 
 cd $BUILD_SOURCESDIRECTORY
 
+branch=$1
+echo "Branch $branch"
+
 echo "Search setup files from `pwd`."
 python --version
 
 pip install -U pip setuptools wheel
 pip list
 
+script_dir=`cd $(dirname $BASH_SOURCE[0]); pwd`
+
+if [[ "$branch" == "dev" ]]; then
+    . $script_dir/../../ci/version.sh post`date -u '+%Y%m%d%H%M%S'`
+fi
+
 for setup_file in $(find src -name 'setup.py' | grep -v azure-cli-testsdk); do
     pushd `dirname $setup_file`
     python setup.py bdist_wheel -d $BUILD_STAGINGDIRECTORY
