@@ -7,7 +7,7 @@ export USERNAME=azureuser
 
 yum --nogpgcheck localinstall /mnt/yum/$YUM_NAME -y
 
-yum install git -y
+yum install git gcc python3-devel -y
 
 ln -s /usr/bin/python3 /usr/bin/python
 ln -s /usr/bin/pip3 /usr/bin/pip
