@@ -6,7 +6,7 @@
 
 from __future__ import print_function
 
-__version__ = "2.17.1"
+__version__ = "2.18.0"
 
 import os
 import sys
@@ -80,6 +80,8 @@ class AzCli(CLI):
 
         self.progress_controller = None
 
+        _configure_knack()
+
     def refresh_request_id(self):
         """Assign a new random GUID as x-ms-client-request-id
 
@@ -851,3 +853,19 @@ def get_default_cli():
                  logging_cls=AzCliLogging,
                  output_cls=AzOutputProducer,
                  help_cls=AzCliHelp)
+
+
+def _configure_knack():
+    """Override consts defined in knack to make them Azure CLI-specific."""
+
+    # Customize status tag messages.
+    from knack.util import status_tag_messages
+    ref_message = "Reference and support levels: https://aka.ms/CLI_refstatus"
+    # Override the preview message.
+    status_tag_messages['preview'] = "{} is in preview and under development. " + ref_message
+    # Override the experimental message.
+    status_tag_messages['experimental'] = "{} is experimental and under development. " + ref_message
+
+    # Allow logs from 'azure' logger to be displayed.
+    from knack.log import cli_logger_names
+    cli_logger_names.append("azure")
