@@ -266,63 +266,6 @@ class TestParser(unittest.TestCase):
                 parser.parse_args('test new-ext reset pos1 pos2'.split())  # test positional args
             self.assertIn("Extension another-ext-name installed. Please rerun your command.", logger_msgs[6])
 
-    @mock.patch('importlib.import_module', _mock_import_lib)
-    @mock.patch('pkgutil.iter_modules', _mock_iter_modules)
-    @mock.patch('azure.cli.core.commands._load_command_loader', _mock_load_command_loader)
-    @mock.patch('azure.cli.core.extension.get_extension_modname', _mock_extension_modname)
-    @mock.patch('azure.cli.core.extension.get_extensions', _mock_get_extensions)
-    def test_parser_failure_recovery_recommendations(self):
-        cli = DummyCli()
-        main_loader = MainCommandsLoader(cli)
-        cli.loader = main_loader
-
-        cli.loader.load_command_table(None)
-
-        parser = cli.parser_cls(cli)
-        parser.load_command_table(cli.loader)
-
-        recommendation_provider_parameters = []
-
-        version = cli.get_cli_version()
-        expected_recommendation_provider_parameters = [
-            # version, command, parameters, extension
-            ExpectedParameters(version, 'test module1', ['--opt'], False),
-            ExpectedParameters(version, 'test extension1', ['--opt'], False),
-            ExpectedParameters(version, 'foo_bar', ['--opt'], False),
-            ExpectedParameters(version, 'test module', ['--opt'], False),
-            ExpectedParameters(version, 'test extension', ['--opt'], True)
-        ]
-
-        def mock_recommendation_provider(*args):
-            recommendation_provider_parameters.append(tuple(args))
-            return []
-
-        AzCliCommandParser.recommendation_provider = mock_recommendation_provider
-
-        faulty_cmd_args = [
-            'test module1 --opt enum_1',
-            'test extension1 --opt enum_1',
-            'test foo_bar --opt enum_3',
-            'test module --opt enum_3',
-            'test extension --opt enum_3'
-        ]
-
-        for text in faulty_cmd_args:
-            with self.assertRaises(SystemExit):
-                parser.parse_args(text.split())
-
-        for i, parameters in enumerate(recommendation_provider_parameters):
-            version, command, parameters, extension = parameters
-            expected = expected_recommendation_provider_parameters[i]
-            self.assertEqual(expected.version, version)
-            self.assertIn(expected.command, command)
-            self.assertEqual(expected.parameters, parameters)
-
-            if expected.has_extension:
-                self.assertIsNotNone(extension)
-            else:
-                self.assertIsNone(extension)
-
 
 class VerifyError(object):  # pylint: disable=too-few-public-methods
 
@@ -337,8 +280,5 @@ class VerifyError(object):  # pylint: disable=too-few-public-methods
         self.called = True
 
 
-ExpectedParameters = namedtuple('ExpectedParameters', ['version', 'command', 'parameters', 'has_extension'])
-
-
 if __name__ == '__main__':
     unittest.main()
