@@ -266,7 +266,7 @@ class ManagedApplicationPreparer(AbstractPreparer, SingleValueReplacer):
 
 # pylint: disable=too-many-instance-attributes
 class VirtualNetworkPreparer(NoTrafficRecordingPreparer, SingleValueReplacer):
-    def __init__(self, name_prefix='clitest.vn',
+    def __init__(self, name_prefix='clitest.vn', location='westus',
                  parameter_name='virtual_network',
                  resource_group_parameter_name='resource_group',
                  resource_group_key=KEY_RESOURCE_GROUP,
@@ -278,6 +278,7 @@ class VirtualNetworkPreparer(NoTrafficRecordingPreparer, SingleValueReplacer):
         super(VirtualNetworkPreparer, self).__init__(
             name_prefix, random_name_length)
         self.cli_ctx = get_dummy_cli()
+        self.location = location
         self.parameter_name = parameter_name
         self.key = key
         self.resource_group_parameter_name = resource_group_parameter_name
@@ -295,8 +296,8 @@ class VirtualNetworkPreparer(NoTrafficRecordingPreparer, SingleValueReplacer):
             tags['job'] = os.environ['ENV_JOB_NAME']
         tags = ' '.join(['{}={}'.format(key, value)
                          for key, value in tags.items()])
-        template = 'az network vnet create --resource-group {} --name {} --subnet-name default --tag ' + tags
-        self.live_only_execute(self.cli_ctx, template.format(self._get_resource_group(**kwargs), name))
+        template = 'az network vnet create --resource-group {} --location {} --name {} --subnet-name default --tag ' + tags
+        self.live_only_execute(self.cli_ctx, template.format(self._get_resource_group(**kwargs), self.location, name))
 
         self.test_class_instance.kwargs[self.key] = name
         return {self.parameter_name: name}
