@@ -26,7 +26,9 @@ from ._format import (
     scope_map_output_format,
     token_output_format,
     token_credential_output_format,
-    agentpool_output_format
+    agentpool_output_format,
+    connected_registry_output_format,
+    connected_registry_list_output_format
 )
 from ._client_factory import (
     cf_acr_registries,
@@ -39,7 +41,8 @@ from ._client_factory import (
     cf_acr_tokens,
     cf_acr_token_credentials,
     cf_acr_private_endpoint_connections,
-    cf_acr_agentpool
+    cf_acr_agentpool,
+    cf_acr_connected_registries
 )
 
 
@@ -155,6 +158,12 @@ def load_command_table(self, _):  # pylint: disable=too-many-statements
         client_factory=cf_acr_agentpool
     )
 
+    acr_connected_registry_util = CliCommandType(
+        operations_tmpl='azure.cli.command_modules.acr.connected_registry#{}',
+        table_transformer=connected_registry_output_format,
+        client_factory=cf_acr_connected_registries
+    )
+
     acr_private_endpoint_connection_util = CliCommandType(
         operations_tmpl='azure.cli.command_modules.acr.private_endpoint_connection#{}',
         client_factory=cf_acr_private_endpoint_connections
@@ -343,3 +352,16 @@ def load_command_table(self, _):  # pylint: disable=too-many-statements
     with self.command_group('acr encryption', acr_custom_util) as g:
         g.show_command('show', 'show_encryption')
         g.command('rotate-key', "rotate_key")
+
+    with self.command_group('acr connected-registry', acr_connected_registry_util, is_preview=True) as g:
+        g.command('create', 'acr_connected_registry_create')
+        g.command('delete', 'acr_connected_registry_delete')
+        g.show_command('show', 'acr_connected_registry_show')
+        g.command('deactivate', 'acr_connected_registry_deactivate')
+        g.command('update', 'acr_connected_registry_update')
+        g.command('install info', 'acr_connected_registry_install_info')
+        g.command('install renew-credentials', 'acr_connected_registry_install_renew_credentials')
+        g.command('list', 'acr_connected_registry_list',
+                  table_transformer=connected_registry_list_output_format)
+        g.command('list-client-tokens', 'acr_connected_registry_list_client_tokens',
+                  table_transformer=token_output_format)
