@@ -6,6 +6,7 @@
 from azure.cli.core.commands.client_factory import get_mgmt_service_client
 from azure.cli.core.commands.parameters import get_resources_in_subscription
 from azure.cli.core.profiles import ResourceType
+from azure.mgmt.msi import ManagedServiceIdentityClient
 from knack.util import CLIError
 
 
@@ -113,3 +114,7 @@ def get_resource_by_name(cli_ctx, resource_name, resource_type):
         raise CLIError(
             "More than one resources with type '{}' are found with name '{}'.".format(
                 resource_type, resource_name))
+
+
+def get_msi_client(cli_ctx, **_):
+    return get_mgmt_service_client(cli_ctx, ManagedServiceIdentityClient)
