@@ -148,6 +148,28 @@ class VnetSubnetIdNamespace:
         self.vnet_subnet_id = vnet_subnet_id
 
 
+class MaxSurgeNamespace:
+    def __init__(self, max_surge):
+        self.max_surge = max_surge
+
+
+class TestMaxSurge(unittest.TestCase):
+    def test_valid_cases(self):
+        valid = ["5", "33%", "1", "100%"]
+        for v in valid:
+            validators.validate_max_surge(MaxSurgeNamespace(v))
+
+    def test_throws_on_string(self):
+        with self.assertRaises(CLIError) as cm:
+            validators.validate_max_surge(MaxSurgeNamespace("foobar"))
+        self.assertTrue('int or percentage' in str(cm.exception), msg=str(cm.exception))
+
+    def test_throws_on_negative(self):
+        with self.assertRaises(CLIError) as cm:
+            validators.validate_max_surge(MaxSurgeNamespace("-3"))
+        self.assertTrue('positive' in str(cm.exception), msg=str(cm.exception))
+
+
 class TestLabels(unittest.TestCase):
     def test_invalid_labels_prefix(self):
         invalid_labels = "k8s##.io/label1=value"
@@ -250,3 +272,34 @@ class TestLabels(unittest.TestCase):
 class LabelsNamespace:
     def __init__(self, labels):
         self.labels = labels
+
+
+class AssignIdentityNamespace:
+    def __init__(self, assign_identity):
+        self.assign_identity = assign_identity
+
+
+class TestAssignIdentity(unittest.TestCase):
+    def test_invalid_identity_id(self):
+        invalid_identity_id = "dummy identity id"
+        namespace = AssignIdentityNamespace(invalid_identity_id)
+        err = ("--assign-identity is not a valid Azure resource ID.")
+
+        with self.assertRaises(CLIError) as cm:
+            validators.validate_assign_identity(namespace)
+        self.assertEqual(str(cm.exception), err)
+
+    def test_valid_identity_id(self):
+        valid_identity_id = "/subscriptions/testid/resourceGroups/MockedResourceGroup/providers/Microsoft.ManagedIdentity/userAssignedIdentities/mockIdentityID"
+        namespace = AssignIdentityNamespace(valid_identity_id)
+        validators.validate_assign_identity(namespace)
+
+    def test_none_identity_id(self):
+        none_identity_id = None
+        namespace = AssignIdentityNamespace(none_identity_id)
+        validators.validate_assign_identity(namespace)
+
+    def test_empty_identity_id(self):
+        empty_identity_id = ""
+        namespace = AssignIdentityNamespace(empty_identity_id)
+        validators.validate_assign_identity(namespace)
