@@ -63,6 +63,17 @@ examples:
              --storage-account-key Ay2ZbdxLnD4OJPT29F6jLPkB6KynOzx85YCObhrw==
 """
 
+helps['apim restore'] = """
+type: command
+short-summary: Restores a backup of an API Management service created using the ApiManagementService_Backup operation on the current service. This is a long running operation and could take several minutes to complete.
+examples:
+  - name: Restores a backup of the API Management service instance
+    text: |-
+        az apim restore --name MyApim -g MyResourceGroup --backup-name myBackup \
+             --storage-account-name mystorageaccount --storage-account-container backups \
+             --storage-account-key Ay2ZbdxLnD4OJPT29F6jLPkB6KynOzx85YCObhrw==
+"""
+
 helps['apim create'] = """
 type: command
 short-summary: Create an API Management service instance.
@@ -264,6 +275,16 @@ examples:
         az apim product delete --resource-group MyResourceGroup  --service-name MyServiceName --product-id MyProductID --delete-subscriptions true
 """
 
+helps['apim product wait'] = """
+type: command
+short-summary: Place the CLI in a waiting state until a condition of an apim product is met.
+examples:
+  - name: Place the CLI in a waiting state until a condition of a apim is met. (autogenerated)
+    text: |
+        az apim product wait --created --resource-group MyResourceGroup --service-name MyServiceName --product-id MyProductID
+    crafted: true
+"""
+
 helps['apim nv list'] = """
 type: command
 short-summary: List API Management Named Values.
