@@ -193,10 +193,13 @@ class BatchDataPlaneScenarioTests(BatchScenarioMixin, ScenarioTest):
                            self.check('commandLine', 'ping 127.0.0.1 -n 30')])
 
         if self.is_live or self.in_recording:
-            time.sleep(120)
-        task_counts = self.batch_cmd('batch job task-counts show --job-id {j_id}').get_output_in_json()
-        self.assertEqual(task_counts["completed"], 0)
-        self.assertEqual(task_counts["active"], 1)
+            time.sleep(10)
+        task_result = self.batch_cmd('batch job task-counts show --job-id {j_id}').get_output_in_json()
+
+        self.assertEqual(task_result["taskCounts"]["completed"], 0)
+        self.assertEqual(task_result["taskCounts"]["active"], 1)
+        self.assertEqual(task_result["taskSlotCounts"]["completed"], 0)
+        self.assertEqual(task_result["taskSlotCounts"]["active"], 1)
 
         self.batch_cmd('batch task delete --job-id {j_id} --task-id aaa --yes')
 
@@ -325,7 +328,9 @@ class BatchDataPlaneScenarioTests(BatchScenarioMixin, ScenarioTest):
         self.batch_cmd('batch pool create --json-file "{json}"')
         self.batch_cmd('batch pool show --pool-id azure-cli-test-json').assert_with_checks([
             self.check('userAccounts[0].name', 'cliTestUser'),
-            self.check('startTask.userIdentity.userName', 'cliTestUser')])
+            self.check('startTask.userIdentity.userName', 'cliTestUser'),
+            self.check('taskSlotsPerNode', 3)
+        ])
 
         # test create pool from non-existant JSON file
         with self.assertRaises(SystemExit):
