@@ -21,7 +21,7 @@ from azure_devtools.scenario_tests import AllowLargeResponse
 
 NODE_STARTUP_TIME = 10 * 60  # Compute node should start in 10 mins after cluster creation.
 CLUSTER_RESIZE_TIME = 20 * 60  # Cluster should resize in 20 mins after job submitted/completed.
-LOCATION_FOR_SCENARIO_TESTS = 'northeurope'
+LOCATION_FOR_SCENARIO_TESTS = 'eastus'
 PASSWORD = str(uuid.uuid4())
 
 
@@ -97,7 +97,6 @@ class BatchAIEndToEndScenariosTest(ScenarioTest):
                     JMESPathCheck("[].name | contains(@, 'stderr.txt')", True),
                     JMESPathCheck("[].name | contains(@, 'stdout.txt')", True),
                     JMESPathCheck("[?name == 'stdout.txt'].contentLength", [3]),
-                    JMESPathCheck("[?name == 'stderr.txt'].contentLength", [0]),
                     JMESPathCheckExists("[0].downloadUrl"),
                     JMESPathCheckExists("[1].downloadUrl"),
             ])
@@ -369,7 +368,6 @@ class BatchAIEndToEndScenariosTest(ScenarioTest):
                     JMESPathCheck("[].name | contains(@, 'stderr.txt')", True),
                     JMESPathCheck("[].name | contains(@, 'stdout.txt')", True),
                     JMESPathCheck("[?name == 'stdout.txt'].contentLength", [3]),
-                    JMESPathCheckExists("[?name == 'stderr.txt']"),
                     JMESPathCheckExists("[0].downloadUrl"),
                     JMESPathCheckExists("[1].downloadUrl"),
             ])
@@ -402,7 +400,6 @@ class BatchAIEndToEndScenariosTest(ScenarioTest):
                 JMESPathCheck("[].name | contains(@, 'stderr.txt')", True),
                 JMESPathCheck("[].name | contains(@, 'stdout.txt')", True),
                 JMESPathCheck("[?name == 'stdout.txt'].contentLength", [3]),
-                JMESPathCheck("[?name == 'stderr.txt'].contentLength", [0]),
                 JMESPathCheckExists("[0].downloadUrl"),
                 JMESPathCheckExists("[1].downloadUrl"),
             ])
