@@ -2,12 +2,13 @@
 # Copyright (c) Microsoft Corporation. All rights reserved.
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
-from azure.cli.testsdk import ResourceGroupPreparer, ScenarioTest, JMESPathCheck
+from azure.cli.testsdk import ResourceGroupPreparer, ScenarioTest, JMESPathCheck, record_only
 from .scenario_mixin import CdnScenarioMixin
 
 
 class CdnOriginScenarioTest(CdnScenarioMixin, ScenarioTest):
 
+    @record_only()  # This tests relies on a specific subscription with existing resources
     @ResourceGroupPreparer()
     def test_origin_crud(self, resource_group):
 
