@@ -5,6 +5,7 @@
 
 # pylint: disable=too-many-statements
 # pylint: disable=line-too-long
+from enum import Enum
 from argcomplete.completers import FilesCompleter
 
 from azure.cli.core.commands.parameters import (
@@ -37,6 +38,11 @@ CASSANDRA_SCHEMA_EXAMPLE = """--schema "{\\"columns\\": [{\\"name\\": \\"columnA
 """
 
 
+class ThroughputTypes(str, Enum):
+    autoscale = "autoscale"
+    manual = "manual"
+
+
 def load_arguments(self, _):
     from knack.arguments import CLIArgumentType
     from azure.mgmt.cosmosdb.models import KeyKind, DefaultConsistencyLevel, DatabaseAccountKind, TriggerType, TriggerOperation, ServerVersion
@@ -107,6 +113,7 @@ def load_arguments(self, _):
     database_name_type = CLIArgumentType(options_list=['--database-name', '-d'], help='Database name.')
     container_name_type = CLIArgumentType(options_list=['--container-name', '-c'], help='Container name.')
     max_throughput_type = CLIArgumentType(options_list=['--max-throughput'], help='The maximum throughput resource can scale to (RU/s). Provided when the resource is autoscale enabled. The minimum value can be 4000 (RU/s)')
+    throughput_type = CLIArgumentType(options_list=['--throughput-type', '-t'], arg_type=get_enum_type(ThroughputTypes), help='The type of throughput to migrate to.')
 
     with self.argument_context('cosmosdb private-endpoint-connection') as c:
         c.argument('private_endpoint_connection_name', options_list=['--name', '-n'], required=False,
@@ -147,6 +154,7 @@ def load_arguments(self, _):
         c.argument('conflict_resolution_policy', options_list=['--conflict-resolution-policy', '-c'], type=shell_safe_json_parse, completer=FilesCompleter(), help='Conflict Resolution Policy, you can enter it as a string or as a file, e.g., --conflict-resolution-policy @policy-file.json or ' + SQL_GREMLIN_CONFLICT_RESOLUTION_POLICY_EXAMPLE)
         c.argument('max_throughput', max_throughput_type)
         c.argument('throughput', help='The throughput of SQL container (RU/s). Default value is 400. Omit this parameter if the database has shared throughput unless the container should have dedicated throughput.')
+        c.argument('analytical_storage_ttl', options_list=['--analytical-storage-ttl', '-t'], type=int, help='Analytical TTL, when analytical storage is enabled.')
 
 # SQL stored procedure
     with self.argument_context('cosmosdb sql stored-procedure') as c:
@@ -282,7 +290,7 @@ def load_arguments(self, _):
     with self.argument_context('cosmosdb gremlin graph throughput') as c:
         c.argument('account_name', account_name_type, id_part=None)
         c.argument('database_name', database_name_type)
-        c.argument('graph_name', options_list=['--name', '-n'], help="Grapth name")
+        c.argument('graph_name', options_list=['--name', '-n'], help="Graph name")
         c.argument('throughput', type=int, help='The throughput Gremlin graph (RU/s).')
         c.argument('max_throughput', max_throughput_type)
 
@@ -291,3 +299,11 @@ def load_arguments(self, _):
         c.argument('table_name', options_list=['--name', '-n'], help="Table name")
         c.argument('throughput', type=int, help='The throughput of Table (RU/s).')
         c.argument('max_throughput', max_throughput_type)
+
+    for scope in ['sql database throughput migrate', 'sql container throughput migrate',
+                  'gremlin database throughput migrate', 'gremlin graph throughput migrate',
+                  'cassandra table throughput migrate', 'cassandra keyspace throughput migrate',
+                  'mongodb collection throughput migrate', 'mongodb database throughput migrate',
+                  'table throughput migrate']:
+        with self.argument_context('cosmosdb {}'.format(scope)) as c:
+            c.argument('throughput_type', throughput_type)
