@@ -276,7 +276,8 @@ def _populate_sql_container_definition(sql_container_resource,
                                        indexing_policy,
                                        unique_key_policy,
                                        partition_key_version,
-                                       conflict_resolution_policy):
+                                       conflict_resolution_policy,
+                                       analytical_storage_ttl):
     if all(arg is None for arg in
            [partition_key_path, partition_key_version, default_ttl, indexing_policy, unique_key_policy, conflict_resolution_policy]):
         return False
@@ -301,6 +302,9 @@ def _populate_sql_container_definition(sql_container_resource,
     if conflict_resolution_policy is not None:
         sql_container_resource.conflict_resolution_policy = conflict_resolution_policy
 
+    if analytical_storage_ttl is not None:
+        sql_container_resource.analytical_storage_ttl = analytical_storage_ttl
+
     return True
 
 
@@ -316,7 +320,8 @@ def cli_cosmosdb_sql_container_create(client,
                                       throughput=None,
                                       max_throughput=None,
                                       unique_key_policy=None,
-                                      conflict_resolution_policy=None):
+                                      conflict_resolution_policy=None,
+                                      analytical_storage_ttl=None):
     """Creates an Azure Cosmos DB SQL container """
     sql_container_resource = SqlContainerResource(id=container_name)
 
@@ -326,7 +331,8 @@ def cli_cosmosdb_sql_container_create(client,
                                        indexing_policy,
                                        unique_key_policy,
                                        partition_key_version,
-                                       conflict_resolution_policy)
+                                       conflict_resolution_policy,
+                                       analytical_storage_ttl)
 
     options = _get_options(throughput, max_throughput)
 
@@ -347,7 +353,8 @@ def cli_cosmosdb_sql_container_update(client,
                                       database_name,
                                       container_name,
                                       default_ttl=None,
-                                      indexing_policy=None):
+                                      indexing_policy=None,
+                                      analytical_storage_ttl=None):
     """Updates an Azure Cosmos DB SQL container """
     logger.debug('reading SQL container')
     sql_container = client.get_sql_container(resource_group_name, account_name, database_name, container_name)
@@ -365,7 +372,8 @@ def cli_cosmosdb_sql_container_update(client,
                                           indexing_policy,
                                           None,
                                           None,
-                                          None):
+                                          None,
+                                          analytical_storage_ttl):
         logger.debug('replacing SQL container')
 
     sql_container_create_update_resource = SqlContainerCreateUpdateParameters(
@@ -945,12 +953,27 @@ def cli_cosmosdb_table_exists(client,
     return True
 
 
-def cli_cosmosdb_sql_database_throughput_update(client, resource_group_name, account_name, database_name, throughput=None, max_throughput=None):
+def cli_cosmosdb_sql_database_throughput_update(client,
+                                                resource_group_name,
+                                                account_name,
+                                                database_name,
+                                                throughput=None,
+                                                max_throughput=None):
     """Update an Azure Cosmos DB SQL database throughput"""
     throughput_update_resource = _get_throughput_settings_update_parameters(throughput, max_throughput)
     return client.update_sql_database_throughput(resource_group_name, account_name, database_name, throughput_update_resource)
 
 
+def cli_cosmosdb_sql_database_throughput_migrate(client,
+                                                 resource_group_name,
+                                                 account_name,
+                                                 database_name,
+                                                 throughput_type):
+    if throughput_type == "autoscale":
+        return client.migrate_sql_database_to_autoscale(resource_group_name, account_name, database_name)
+    return client.migrate_sql_database_to_manual_throughput(resource_group_name, account_name, database_name)
+
+
 def cli_cosmosdb_sql_container_throughput_update(client,
                                                  resource_group_name,
                                                  account_name,
@@ -967,6 +990,18 @@ def cli_cosmosdb_sql_container_throughput_update(client,
                                                   throughput_update_resource)
 
 
+def cli_cosmosdb_sql_container_throughput_migrate(client,
+                                                  resource_group_name,
+                                                  account_name,
+                                                  database_name,
+                                                  container_name,
+                                                  throughput_type):
+    """Migrate an Azure Cosmos DB SQL container throughput"""
+    if throughput_type == "autoscale":
+        return client.migrate_sql_container_to_autoscale(resource_group_name, account_name, database_name, container_name)
+    return client.migrate_sql_container_to_manual_throughput(resource_group_name, account_name, database_name, container_name)
+
+
 def cli_cosmosdb_mongodb_database_throughput_update(client,
                                                     resource_group_name,
                                                     account_name,
@@ -981,6 +1016,17 @@ def cli_cosmosdb_mongodb_database_throughput_update(client,
                                                       throughput_update_resource)
 
 
+def cli_cosmosdb_mongodb_database_throughput_migrate(client,
+                                                     resource_group_name,
+                                                     account_name,
+                                                     database_name,
+                                                     throughput_type):
+    """Migrate an Azure Cosmos DB MongoDB database throughput"""
+    if throughput_type == "autoscale":
+        return client.migrate_mongo_db_database_to_autoscale(resource_group_name, account_name, database_name)
+    return client.migrate_mongo_db_database_to_manual_throughput(resource_group_name, account_name, database_name)
+
+
 def cli_cosmosdb_mongodb_collection_throughput_update(client,
                                                       resource_group_name,
                                                       account_name,
@@ -997,6 +1043,18 @@ def cli_cosmosdb_mongodb_collection_throughput_update(client,
                                                         throughput_update_resource)
 
 
+def cli_cosmosdb_mongodb_collection_throughput_migrate(client,
+                                                       resource_group_name,
+                                                       account_name,
+                                                       database_name,
+                                                       collection_name,
+                                                       throughput_type):
+    """Migrate an Azure Cosmos DB MongoDB collection throughput"""
+    if throughput_type == "autoscale":
+        return client.migrate_mongo_db_collection_to_autoscale(resource_group_name, account_name, database_name, collection_name)
+    return client.migrate_mongo_db_collection_to_manual_throughput(resource_group_name, account_name, database_name, collection_name)
+
+
 def cli_cosmosdb_cassandra_keyspace_throughput_update(client,
                                                       resource_group_name,
                                                       account_name,
@@ -1011,6 +1069,17 @@ def cli_cosmosdb_cassandra_keyspace_throughput_update(client,
                                                        throughput_update_resource)
 
 
+def cli_cosmosdb_cassandra_keyspace_throughput_migrate(client,
+                                                       resource_group_name,
+                                                       account_name,
+                                                       keyspace_name,
+                                                       throughput_type):
+    """Migrate an Azure Cosmos DB Cassandra keyspace throughput"""
+    if throughput_type == "autoscale":
+        return client.migrate_cassandra_keyspace_to_autoscale(resource_group_name, account_name, keyspace_name)
+    return client.migrate_cassandra_keyspace_to_manual_throughput(resource_group_name, account_name, keyspace_name)
+
+
 def cli_cosmosdb_cassandra_table_throughput_update(client,
                                                    resource_group_name,
                                                    account_name,
@@ -1027,6 +1096,18 @@ def cli_cosmosdb_cassandra_table_throughput_update(client,
                                                     throughput_update_resource)
 
 
+def cli_cosmosdb_cassandra_table_throughput_migrate(client,
+                                                    resource_group_name,
+                                                    account_name,
+                                                    keyspace_name,
+                                                    table_name,
+                                                    throughput_type):
+    """Migrate an Azure Cosmos DB Cassandra table throughput"""
+    if throughput_type == "autoscale":
+        return client.migrate_cassandra_table_to_autoscale(resource_group_name, account_name, keyspace_name, table_name)
+    return client.migrate_cassandra_table_to_manual_throughput(resource_group_name, account_name, keyspace_name, table_name)
+
+
 def cli_cosmosdb_gremlin_database_throughput_update(client,
                                                     resource_group_name,
                                                     account_name,
@@ -1041,6 +1122,17 @@ def cli_cosmosdb_gremlin_database_throughput_update(client,
                                                      throughput_update_resource)
 
 
+def cli_cosmosdb_gremlin_database_throughput_migrate(client,
+                                                     resource_group_name,
+                                                     account_name,
+                                                     database_name,
+                                                     throughput_type):
+    """Migrate an Azure Cosmos DB Gremlin database throughput"""
+    if throughput_type == "autoscale":
+        return client.migrate_gremlin_database_to_autoscale(resource_group_name, account_name, database_name)
+    return client.migrate_gremlin_database_to_manual_throughput(resource_group_name, account_name, database_name)
+
+
 def cli_cosmosdb_gremlin_graph_throughput_update(client,
                                                  resource_group_name,
                                                  account_name,
@@ -1057,6 +1149,18 @@ def cli_cosmosdb_gremlin_graph_throughput_update(client,
                                                   throughput_update_resource)
 
 
+def cli_cosmosdb_gremlin_graph_throughput_migrate(client,
+                                                  resource_group_name,
+                                                  account_name,
+                                                  database_name,
+                                                  graph_name,
+                                                  throughput_type):
+    """Migrate an Azure Cosmos DB Gremlin database throughput"""
+    if throughput_type == "autoscale":
+        return client.migrate_gremlin_graph_to_autoscale(resource_group_name, account_name, database_name, graph_name)
+    return client.migrate_gremlin_graph_to_manual_throughput(resource_group_name, account_name, database_name, graph_name)
+
+
 def cli_cosmosdb_table_throughput_update(client,
                                          resource_group_name,
                                          account_name,
@@ -1068,6 +1172,17 @@ def cli_cosmosdb_table_throughput_update(client,
     return client.update_table_throughput(resource_group_name, account_name, table_name, throughput_update_resource)
 
 
+def cli_cosmosdb_table_throughput_migrate(client,
+                                          resource_group_name,
+                                          account_name,
+                                          table_name,
+                                          throughput_type):
+    """Migrate an Azure Cosmos DB table throughput"""
+    if throughput_type == "autoscale":
+        return client.migrate_table_to_autoscale(resource_group_name, account_name, table_name)
+    return client.migrate_table_to_manual_throughput(resource_group_name, account_name, table_name)
+
+
 def _get_throughput_settings_update_parameters(throughput=None, max_throughput=None):
 
     if throughput and max_throughput:
