@@ -101,7 +101,7 @@ def call_aladdin_service(query):
     subscription_id = telemetry_core._get_azure_subscription_id()  # pylint: disable=protected-access
 
     # Used for DDOS protection and rate limiting
-    user_id = telemetry_core._get_user_azure_id()  # pylint: disable=protected-access
+    user_id = telemetry_core._get_installation_id()  # pylint: disable=protected-access
     hashed_user_id = hashlib.sha256(user_id.encode('utf-8')).hexdigest()
 
     context = {
