@@ -35,7 +35,9 @@ def create_cluster(cmd, client, cluster_name, resource_group_name, cluster_type,
                    encryption_algorithm='RSA-OAEP', encryption_in_transit=None,
                    autoscale_type=None, autoscale_min_workernode_count=None, autoscale_max_workernode_count=None,
                    timezone=None, days=None, time=None, autoscale_workernode_count=None,
-                   encryption_at_host=None, esp=False, idbroker=False, no_validation_timeout=False):
+                   encryption_at_host=None, esp=False, idbroker=False,
+                   resource_provider_connection=None, enable_private_link=None,
+                   no_validation_timeout=False):
     from .util import build_identities_info, build_virtual_network_profile, parse_domain_name, \
         get_storage_account_endpoint, validate_esp_cluster_create_params
     from azure.mgmt.hdinsight.models import ClusterCreateParametersExtended, ClusterCreateProperties, OSType, \
@@ -43,7 +45,8 @@ def create_cluster(cmd, client, cluster_name, resource_group_name, cluster_type,
         StorageProfile, StorageAccount, DataDisksGroups, SecurityProfile, \
         DirectoryType, DiskEncryptionProperties, Tier, SshProfile, SshPublicKey, \
         KafkaRestProperties, ClientGroupInfo, EncryptionInTransitProperties, \
-        Autoscale, AutoscaleCapacity, AutoscaleRecurrence, AutoscaleSchedule, AutoscaleTimeAndCapacity
+        Autoscale, AutoscaleCapacity, AutoscaleRecurrence, AutoscaleSchedule, AutoscaleTimeAndCapacity, \
+        NetworkProperties, PrivateLink
 
     validate_esp_cluster_create_params(esp, cluster_name, resource_group_name, cluster_type,
                                        subnet, domain, cluster_admin_account, assign_identity,
@@ -341,6 +344,12 @@ def create_cluster(cmd, client, cluster_name, resource_group_name, cluster_type,
         is_encryption_in_transit_enabled=encryption_in_transit
     )
 
+    # relay outbound and private link
+    network_properties = (resource_provider_connection or enable_private_link) and NetworkProperties(
+        resource_provider_connection=resource_provider_connection,
+        private_link=PrivateLink.enabled if enable_private_link is True else PrivateLink.disabled
+    )
+
     create_params = ClusterCreateParametersExtended(
         location=location,
         tags=tags,
@@ -363,7 +372,8 @@ def create_cluster(cmd, client, cluster_name, resource_group_name, cluster_type,
             disk_encryption_properties=disk_encryption_properties,
             kafka_rest_properties=kafka_rest_properties,
             min_supported_tls_version=minimal_tls_version,
-            encryption_in_transit_properties=encryption_in_transit_properties
+            encryption_in_transit_properties=encryption_in_transit_properties,
+            network_properties=network_properties
         ),
         identity=cluster_identity
     )
