@@ -399,9 +399,9 @@ examples:
   - name: Create an IoT Hub with the free pricing tier F1, in the region of the resource group.
     text: >
         az iot hub create --resource-group MyResourceGroup --name MyIotHub --sku F1 --partition-count 2
-  - name: Create an IoT Hub with the standard pricing tier S1 and 4 partitions, in the 'westus' region.
+  - name: Create an IoT Hub with the standard pricing tier S1 and 4 partitions, in the 'westus' region, with tags.
     text: >
-        az iot hub create --resource-group MyResourceGroup --name MyIotHub --location westus
+        az iot hub create --resource-group MyResourceGroup --name MyIotHub --location westus --tags a=b c=d
 """
 
 helps['iot hub delete'] = """
@@ -764,9 +764,9 @@ examples:
     text: |
         az iot hub update --name MyIotHub --set properties.allocationPolicy="GeoLatency"
     crafted: true
-  - name: Update units of an IoT Hub to 2
+  - name: Update units of an IoT Hub to 2 and add tags
     text: >
-        az iot hub update -n MyIotHub --unit 2
+        az iot hub update -n MyIotHub --unit 2 --tags a=b c=d
   - name: Update pricing tier for an IoT Hub as S2
     text: >
         az iot hub update -n MyIotHub --sku S2
