@@ -22,7 +22,12 @@ def keep_max_results(output, **command_args):
 
 
 def filter_out_managed_resources(output, **command_args):  # pylint: disable=unused-argument
-    return [_ for _ in output if not getattr(_, 'managed')] if output else output
+    is_kv_transform = command_args.get('kv_transform')
+    if is_kv_transform:
+        if command_args.get('include_managed'):
+            return output
+        return [_ for _ in output if not getattr(_, 'managed')] if output else output
+    return output
 
 
 def _extract_subresource_name_from_single_output(output, id_parameter):
