@@ -12,7 +12,7 @@ from azure.cli.core.commands.client_factory import get_subscription_id
 from azure.cli.core.util import CLIError, sdk_no_wait
 from azure.cli.core.local_context import ALL
 from ._client_factory import get_mysql_flexible_management_client, cf_mysql_flexible_firewall_rules, \
-    cf_mysql_flexible_db, cf_mysql_check_resource_availability
+    cf_mysql_flexible_db
 from ._flexible_server_util import resolve_poller, generate_missing_parameters, create_firewall_rule, \
     parse_public_access_input, generate_password, parse_maintenance_window, get_mysql_list_skus_info, \
     DEFAULT_LOCATION_MySQL
@@ -41,98 +41,88 @@ def flexible_server_create(cmd, client, resource_group_name=None, server_name=No
     storage_mb *= 1024
 
     from azure.mgmt.rdbms import mysql_flexibleservers
-    try:
-        db_context = DbContext(
-            azure_sdk=mysql_flexibleservers, cf_firewall=cf_mysql_flexible_firewall_rules, cf_db=cf_mysql_flexible_db,
-            logging_name='MySQL', command_group='mysql', server_client=client)
+    # try:
+    db_context = DbContext(
+        azure_sdk=mysql_flexibleservers, cf_firewall=cf_mysql_flexible_firewall_rules, cf_db=cf_mysql_flexible_db,
+        logging_name='MySQL', command_group='mysql', server_client=client)
 
-        # Raise error when user passes values for both parameters
-        if subnet_arm_resource_id is not None and public_access is not None:
-            raise CLIError("Incorrect usage : A combination of the parameters --subnet "
-                           "and --public_access is invalid. Use either one of them.")
+    # Raise error when user passes values for both parameters
+    if subnet_arm_resource_id is not None and public_access is not None:
+        raise CLIError("Incorrect usage : A combination of the parameters --subnet "
+                       "and --public_access is invalid. Use either one of them.")
 
-        # When address space parameters are passed, the only valid combination is : --vnet, --subnet, --vnet-address-prefix, --subnet-address-prefix
-        # pylint: disable=too-many-boolean-expressions
-        if (vnet_address_prefix is not None) or (subnet_address_prefix is not None):
-            if (((vnet_address_prefix is not None) and (subnet_address_prefix is None)) or
-                    ((vnet_address_prefix is None) and (subnet_address_prefix is not None)) or
-                    ((vnet_address_prefix is not None) and (subnet_address_prefix is not None) and
-                     ((vnet_resource_id is None) or (subnet_arm_resource_id is None)))):
-                raise CLIError("Incorrect usage : "
-                               "--vnet, --subnet, --vnet-address-prefix, --subnet-address-prefix must be supplied together.")
+    # When address space parameters are passed, the only valid combination is : --vnet, --subnet, --vnet-address-prefix, --subnet-address-prefix
+    # pylint: disable=too-many-boolean-expressions
+    if (vnet_address_prefix is not None) or (subnet_address_prefix is not None):
+        if (((vnet_address_prefix is not None) and (subnet_address_prefix is None)) or
+                ((vnet_address_prefix is None) and (subnet_address_prefix is not None)) or
+                ((vnet_address_prefix is not None) and (subnet_address_prefix is not None) and
+                 ((vnet_resource_id is None) or (subnet_arm_resource_id is None)))):
+            raise CLIError("Incorrect usage : "
+                           "--vnet, --subnet, --vnet-address-prefix, --subnet-address-prefix must be supplied together.")
 
-        server_result = firewall_id = subnet_id = None
+    server_result = firewall_id = subnet_id = None
 
-        # Check availability for server name if it is supplied by the user
-        if server_name is not None:
-            check_name_client = cf_mysql_check_resource_availability(cmd.cli_ctx, None)
-            server_availability = check_name_client.execute(server_name, DELEGATION_SERVICE_NAME)
-            if not server_availability.name_available:
-                raise CLIError(server_availability.message)
+    # Populate desired parameters
+    location, resource_group_name, server_name = generate_missing_parameters(cmd, location, resource_group_name,
+                                                                             server_name, 'mysql')
+    server_name = server_name.lower()
 
-        # Populate desired parameters
-        location, resource_group_name, server_name = generate_missing_parameters(cmd, location, resource_group_name,
-                                                                                 server_name, 'mysql')
-        server_name = server_name.lower()
+    # Handle Vnet scenario
+    if (subnet_arm_resource_id is not None) or (vnet_resource_id is not None):
+        subnet_id = prepare_vnet(cmd, server_name, vnet_resource_id, subnet_arm_resource_id, resource_group_name,
+                                 location, DELEGATION_SERVICE_NAME, vnet_address_prefix, subnet_address_prefix)
+        delegated_subnet_arguments = mysql_flexibleservers.models.DelegatedSubnetArguments(
+            subnet_arm_resource_id=subnet_id)
+    elif public_access is None and subnet_arm_resource_id is None and vnet_resource_id is None:
+        subnet_id = create_vnet(cmd, server_name, location, resource_group_name,
+                                DELEGATION_SERVICE_NAME)
+        delegated_subnet_arguments = mysql_flexibleservers.models.DelegatedSubnetArguments(
+            subnet_arm_resource_id=subnet_id)
+    else:
+        delegated_subnet_arguments = None
 
-        # Handle Vnet scenario
-        if (subnet_arm_resource_id is not None) or (vnet_resource_id is not None):
-            subnet_id = prepare_vnet(cmd, server_name, vnet_resource_id, subnet_arm_resource_id, resource_group_name,
-                                     location, DELEGATION_SERVICE_NAME, vnet_address_prefix, subnet_address_prefix)
-            delegated_subnet_arguments = mysql_flexibleservers.models.DelegatedSubnetArguments(
-                subnet_arm_resource_id=subnet_id)
-        elif public_access is None and subnet_arm_resource_id is None and vnet_resource_id is None:
-            subnet_id = create_vnet(cmd, server_name, location, resource_group_name,
-                                    DELEGATION_SERVICE_NAME)
-            delegated_subnet_arguments = mysql_flexibleservers.models.DelegatedSubnetArguments(
-                subnet_arm_resource_id=subnet_id)
-        else:
-            delegated_subnet_arguments = None
+    administrator_login_password = generate_password(administrator_login_password)
+    if server_result is None:
+        # Create mysql server
+        # Note : passing public_access has no effect as the accepted values are 'Enabled' and 'Disabled'. So the value ends up being ignored.
+        server_result = _create_server(db_context, cmd, resource_group_name, server_name, location,
+                                       backup_retention,
+                                       sku_name, tier, storage_mb, administrator_login,
+                                       administrator_login_password,
+                                       version, tags, delegated_subnet_arguments, assign_identity, public_access,
+                                       high_availability, zone)
 
-        administrator_login_password = generate_password(administrator_login_password)
-        if server_result is None:
-            # Create mysql server
-            # Note : passing public_access has no effect as the accepted values are 'Enabled' and 'Disabled'. So the value ends up being ignored.
-            server_result = _create_server(db_context, cmd, resource_group_name, server_name, location,
-                                           backup_retention,
-                                           sku_name, tier, storage_mb, administrator_login,
-                                           administrator_login_password,
-                                           version, tags, delegated_subnet_arguments, assign_identity, public_access,
-                                           high_availability, zone)
+        # Adding firewall rule
+        if public_access is not None and str(public_access).lower() != 'none':
+            if str(public_access).lower() == 'all':
+                start_ip, end_ip = '0.0.0.0', '255.255.255.255'
+            else:
+                start_ip, end_ip = parse_public_access_input(public_access)
+            firewall_id = create_firewall_rule(db_context, cmd, resource_group_name, server_name, start_ip, end_ip)
 
-            # Adding firewall rule
-            if public_access is not None and str(public_access).lower() != 'none':
-                if str(public_access).lower() == 'all':
-                    start_ip, end_ip = '0.0.0.0', '255.255.255.255'
-                else:
-                    start_ip, end_ip = parse_public_access_input(public_access)
-                firewall_id = create_firewall_rule(db_context, cmd, resource_group_name, server_name, start_ip, end_ip)
+        # Create mysql database if it does not exist
+        if database_name is None:
+            database_name = DEFAULT_DB_NAME
+        _create_database(db_context, cmd, resource_group_name, server_name, database_name)
 
-            # Create mysql database if it does not exist
-            if database_name is None:
-                database_name = DEFAULT_DB_NAME
-            _create_database(db_context, cmd, resource_group_name, server_name, database_name)
+    user = server_result.administrator_login
+    server_id = server_result.id
+    loc = server_result.location
+    version = server_result.version
+    sku = server_result.sku.name
+    host = server_result.fully_qualified_domain_name
 
-        user = server_result.administrator_login
-        server_id = server_result.id
-        loc = server_result.location
-        version = server_result.version
-        sku = server_result.sku.name
-        host = server_result.fully_qualified_domain_name
+    logger.warning('Make a note of your password. If you forget, you would have to reset your password with'
+                   '\'az mysql flexible-server update -n %s -g %s -p <new-password>\'.',
+                   server_name, resource_group_name)
 
-        logger.warning('Make a note of your password. If you forget, you would have to reset your password with'
-                       '\'az mysql flexible-server update -n %s -g %s -p <new-password>\'.',
-                       server_name, resource_group_name)
+    _update_local_contexts(cmd, server_name, resource_group_name, location, user)
 
-        _update_local_contexts(cmd, server_name, resource_group_name, location, user)
-
-        return _form_response(user, sku, loc, server_id, host, version,
-                              administrator_login_password if administrator_login_password is not None else '*****',
-                              _create_mysql_connection_string(host, database_name, user, administrator_login_password),
-                              database_name, firewall_id, subnet_id)
-
-    except Exception as ex:  # pylint: disable=broad-except
-        logger.error(ex)
+    return _form_response(user, sku, loc, server_id, host, version,
+                          administrator_login_password if administrator_login_password is not None else '*****',
+                          _create_mysql_connection_string(host, database_name, user, administrator_login_password),
+                          database_name, firewall_id, subnet_id)
 
 
 def flexible_server_restore(cmd, client, resource_group_name, server_name, source_server, restore_point_in_time, location=None, no_wait=False):
@@ -258,6 +248,7 @@ def flexible_server_update_custom_func(cmd, instance,
 def server_delete_func(cmd, client, resource_group_name=None, server_name=None, yes=None):
     confirm = yes
     result = None  # default return value
+
     if not yes:
         confirm = user_confirmation(
             "Are you sure you want to delete the server '{0}' in resource group '{1}'".format(server_name,
@@ -269,8 +260,12 @@ def server_delete_func(cmd, client, resource_group_name=None, server_name=None,
             if cmd.cli_ctx.local_context.is_on:
                 local_context_file = cmd.cli_ctx.local_context._get_local_context_file()  # pylint: disable=protected-access
                 local_context_file.remove_option('mysql flexible-server', 'server_name')
+                local_context_file.remove_option('mysql flexible-server', 'administrator_login')
+                local_context_file.remove_option('mysql flexible-server', 'database_name')
+
         except Exception as ex:  # pylint: disable=broad-except
             logger.error(ex)
+            raise CLIError(ex)
     return result
 
 
