@@ -94,7 +94,9 @@ class ServerMgmtScenarioTest(ScenarioTest):
         servers = [self.create_random_name(SERVER_NAME_PREFIX, SERVER_NAME_MAX_LENGTH),
                    self.create_random_name('azuredbclirestore', SERVER_NAME_MAX_LENGTH),
                    self.create_random_name('azuredbcligeorestore', SERVER_NAME_MAX_LENGTH),
-                   self.create_random_name('azuredbcliinfraencrypt', SERVER_NAME_MAX_LENGTH)]
+                   self.create_random_name('azuredbcliinfraencrypt', SERVER_NAME_MAX_LENGTH),
+                   self.create_random_name('azuredbcliupgrade', SERVER_NAME_MAX_LENGTH)]
+
         admin_login = 'cloudsa'
         admin_passwords = ['SecretPassword123', 'SecretPassword456']
         edition = 'GeneralPurpose'
@@ -116,6 +118,9 @@ class ServerMgmtScenarioTest(ScenarioTest):
         infrastructureEncryption = 'Enabled'
         geoloc = 'eastus'
 
+        if self.cli_ctx.local_context.is_on:
+            self.cmd('local-context off')
+
         list_checks = [JMESPathCheck('name', servers[0]),
                        JMESPathCheck('resourceGroup', resource_group_1),
                        JMESPathCheck('administratorLogin', admin_login),
@@ -288,6 +293,32 @@ class ServerMgmtScenarioTest(ScenarioTest):
         self.cmd('{} server list'.format(database_engine),
                  checks=[JMESPathCheck('type(@)', 'array')])
 
+        connection_string = self.cmd('{} server show-connection-string -s {}'
+                                     .format(database_engine, servers[0])).get_output_in_json()
+
+        self.assertIn('jdbc', connection_string['connectionStrings'])
+        self.assertIn('node.js', connection_string['connectionStrings'])
+        self.assertIn('php', connection_string['connectionStrings'])
+        self.assertIn('python', connection_string['connectionStrings'])
+        self.assertIn('ruby', connection_string['connectionStrings'])
+        # test mysql version upgrade
+        if database_engine == 'mysql':
+            self.cmd('{} server create -g {} --name {} -l {} '
+                     '--admin-user {} --admin-password {} '
+                     '--sku-name {} --tags key=1 --geo-redundant-backup {} '
+                     '--backup-retention {} --version 5.6'
+                     .format(database_engine, resource_group_1, servers[4], loc,
+                             admin_login, admin_passwords[0], skuname,
+                             geoRedundantBackup, backupRetention),
+                     checks=[
+                         JMESPathCheck('version', '5.6')])
+            self.cmd('{} server upgrade -g {} --name {} --target-server-version 5.7'
+                     .format(database_engine, resource_group_1, servers[4]), checks=NoneCheck())
+            result = self.cmd('{} server show -g {} -n {}'
+                              .format(database_engine, resource_group_1, servers[4])).get_output_in_json()
+            server_version = result['version']
+            self.assertEqual(server_version, '5.7')
+
         # test delete server
         self.cmd('{} server delete -g {} --name {} --yes'
                  .format(database_engine, resource_group_1, servers[0]), checks=NoneCheck())
@@ -296,6 +327,9 @@ class ServerMgmtScenarioTest(ScenarioTest):
         if database_engine != 'mariadb':
             self.cmd('{} server delete -g {} -n {} --yes'
                      .format(database_engine, resource_group_1, servers[3]), checks=NoneCheck())
+        if database_engine == 'mysql':
+            self.cmd('{} server delete -g {} -n {} --yes'
+                     .format(database_engine, resource_group_1, servers[4]), checks=NoneCheck())
 
         # test list server should be 0
         self.cmd('{} server list -g {}'.format(database_engine, resource_group_1), checks=[NoneCheck()])
