@@ -493,7 +493,7 @@ short-summary: Place the CLI in a waiting state until a deployment condition is
 examples:
   - name: Place the CLI in a waiting state until a deployment condition is met. (autogenerated)
     text: |
-        az deployment sub wait --name MyDeployment --created
+        az deployment sub wait --created --name MyDeployment
     crafted: true
 """
 
@@ -505,6 +505,11 @@ short-summary: Manage deployment operations at subscription scope.
 helps['deployment operation sub list'] = """
 type: command
 short-summary: List deployment operations at subscription scope.
+examples:
+  - name: List deployment operations at subscription scope. (autogenerated)
+    text: |
+        az deployment operation sub list --name mydeployment
+    crafted: true
 """
 
 helps['deployment operation sub show'] = """
@@ -759,6 +764,10 @@ parameters:
 examples:
   - name: Validate whether a template is valid at management group.
     text: az deployment mg validate --management-group-id testmg --location WestUS --template-file {template-file}
+  - name: Validate whether a template is valid at management group. (autogenerated)
+    text: |
+        az deployment mg validate --location WestUS --management-group-id testmg --name mydeployment --parameters @myparameters.json --template-file azuredeploy.json
+    crafted: true
 """
 
 helps['deployment mg what-if'] = """
@@ -923,6 +932,10 @@ parameters:
 examples:
   - name: Validate whether a template is valid at tenant scope.
     text: az deployment tenant validate --location WestUS --template-file {template-file}
+  - name: Validate whether a template is valid at tenant scope. (autogenerated)
+    text: |
+        az deployment tenant validate --location WestUS --name mydeployment --parameters @myparameters.json --template-file azuredeploy.json
+    crafted: true
 """
 
 helps['deployment tenant what-if'] = """
@@ -1434,7 +1447,7 @@ short-summary: Delete a managed application.
 examples:
   - name: Delete a managed application. (autogenerated)
     text: |
-        az managedapp delete --name MyManagedApplication --resource-group MyResourceGroup
+        az managedapp delete --name MyManagedApplication --resource-group MyResourceGroup --subscription MySubscription
     crafted: true
 """
 
@@ -1772,6 +1785,9 @@ examples:
     text: |
         az provider register --namespace 'Microsoft.PolicyInsights'
     crafted: true
+  - name: Register a provider from RPaaS.
+    text: |
+        az provider register -n 'Microsoft.Confluent' --accept-terms
 """
 
 helps['provider unregister'] = """
@@ -2046,13 +2062,17 @@ helps['resource update'] = """
 type: command
 short-summary: Update a resource.
 examples:
-  - name: Update a webapp. (autogenerated)
-    text: |
-        az resource update --ids /subscriptions/{SubID}/resourceGroups/{ResourceGroup}/providers/Microsoft.Web/sites/{WebApp} --set tags.key=value
-    crafted: true
   - name: Update a webapp by using the latest api-version whether this version is a preview version.
     text: >
         az resource update --ids /subscriptions/{SubID}/resourceGroups/{ResourceGroup}/providers/Microsoft.Web/sites/{WebApp} --set tags.key=value --latest-include-preview
+  - name: Update a resource. (autogenerated)
+    text: |
+        az resource update --ids $id --set properties.connectionType=Proxy
+    crafted: true
+  - name: Update a resource. (autogenerated)
+    text: |
+        az resource update --name myresource --resource-group myresourcegroup --resource-type subnets --set tags.key=value
+    crafted: true
 """
 
 helps['resource wait'] = """
@@ -2201,11 +2221,11 @@ type: command
 short-summary: Create a template spec and or template spec version.
 examples:
   - name: Create a template spec.
-    text: az ts create -g testRG --name TemplateSpecName -l WestUS --display-name "MyDisplayName" --description "Simple template spec"
+    text: az ts create -g testRG --name TemplateSpecName -l WestUS --display-name "MyDisplayName" --description "Simple template spec" --tags key1=value1
   - name: Create a template spec version.
-    text: az ts create -g testRG --name TemplateSpecName -v 2.0 -l WestUS --template-file templateSpec.json --version-description "Less simple template spec"
+    text: az ts create -g testRG --name TemplateSpecName -v 2.0 -l WestUS --template-file templateSpec.json --version-description "Less simple template spec" --tags key1=value1 key3=value3
   - name: Create a template spec and a version of the template spec.
-    text: az ts create -g testRG --name TemplateSpecName -v 1.0 -l WestUS --template-file templateSpec.json --display-name "MyDisplayName" --description "Simple template spec" --version-description "Version of simple template spec"
+    text: az ts create -g testRG --name TemplateSpecName -v 1.0 -l WestUS --template-file templateSpec.json --display-name "MyDisplayName" --description "Simple template spec" --version-description "Version of simple template spec" --tags key1=value1 key2=value2
 """
 
 helps['ts update'] = """
@@ -2214,12 +2234,15 @@ short-summary: Update a template spec version.
 examples:
   - name: Update the template content of a template spec or template spec version based on the resource ID.
     text: az ts update --template-spec resourceID -f updatedFile.json
-  - name: Update the display name of a template spec based on the resource ID.
-    text: az ts update --template-spec resourceID --display-name "NewParentDisplayName"
-  - name: Update the description of a template spec version.
-    text: az ts update -g ExistingRG --name ExistingName -v 3.0 --version-description "New description"
+  - name: Update the display name and tag(s) of a template spec based on the resource ID.
+    text: az ts update --template-spec resourceID --display-name "NewParentDisplayName" --tags key1=value1
+  - name: Update the description of a template spec version with no prompt.
+    text: az ts update -g ExistingRG --name ExistingName -v 3.0 --version-description "New description" --yes
   - name: Update all the properties of a template spec version.
     text: az ts update -g ExistingRG --name ExistingName -v 3.0 -f updatedTemplate.json --display-name "New parent display name" --description "New parent description" --version-description "New child description"
+  - name: Remove tag(s) from template spec version with no prompt.
+    text: az ts update -g ExistingRG --name ExistingName -v 3.0 -f updatedTemplate.json --tags --yes
+
 """
 
 helps['ts show'] = """
