@@ -17,7 +17,7 @@ from azure.cli.command_modules.resource._client_factory import (
     cf_resource_groups, cf_providers, cf_features, cf_tags, cf_deployments,
     cf_deployment_operations, cf_policy_definitions, cf_policy_set_definitions, cf_resource_links,
     cf_resource_deploymentscripts, cf_resource_managedapplications, cf_resource_managedappdefinitions, cf_management_groups, cf_management_group_subscriptions, cf_resource_templatespecs)
-from azure.cli.command_modules.resource._validators import process_deployment_create_namespace, _validate_template_input, _validate_template_spec, _validate_template_spec_out
+from azure.cli.command_modules.resource._validators import process_deployment_create_namespace, process_ts_create_or_update_namespace, _validate_template_spec, _validate_template_spec_out
 
 from ._exception_handler import managementgroups_exception_handler
 
@@ -298,8 +298,8 @@ def load_command_table(self, _):
         g.custom_command('delete', 'delete_deployment_script', confirmation=True)
 
     with self.command_group('ts', resource_templatespecs_sdk, resource_type=ResourceType.MGMT_RESOURCE_TEMPLATESPECS, is_preview=True, min_api='2019-06-01-preview') as g:
-        g.custom_command('create', 'create_template_spec', validator=_validate_template_input)
-        g.custom_command('update', 'update_template_spec', validator=_validate_template_input, confirmation=True)
+        g.custom_command('create', 'create_template_spec', validator=process_ts_create_or_update_namespace)
+        g.custom_command('update', 'update_template_spec', validator=process_ts_create_or_update_namespace, confirmation=True)
         g.custom_command('export', 'export_template_spec', validator=_validate_template_spec_out)
         g.custom_show_command('show', 'get_template_spec', validator=_validate_template_spec)
         g.custom_command('list', 'list_template_specs')
