@@ -9,21 +9,21 @@ ROLE_COMMAND_MAX_RETRY = 20
 ROLE_COMMAND_SLEEP_DURATION = 10
 
 
-def cmd_with_retry(self, *args, sleep_duration=ROLE_COMMAND_SLEEP_DURATION, max_retry=ROLE_COMMAND_MAX_RETRY, **kwargs):
-    """Retry self.cmd and checks until success."""
+def retry(func, sleep_duration=ROLE_COMMAND_SLEEP_DURATION, max_retry=ROLE_COMMAND_MAX_RETRY):
+    """Retry func until success."""
     # Due to unstable role definition ARIs: https://github.com/Azure/azure-cli/issues/3187
     import time
-    result = None
-    while not result:
+    while True:
         try:
-            result = self.cmd(*args, **kwargs)
+            return func()
         except (AssertionError, CLIError):
+            # AssertionError is raised by checks in self.cmd or self.assert*
+            # CLIError is raised by failed command execution
             if max_retry > 0:
                 max_retry -= 1
                 time.sleep(sleep_duration)
             else:
                 raise
-    return result
 
 
 def escape_apply_kwargs(val):
