@@ -19,6 +19,8 @@ from ._format import (
     server_table_format,
     usage_table_format,
     LongRunningOperationResultTransform,
+    mi_transform,
+    mi_list_transform
 )
 
 from ._util import (
@@ -26,6 +28,7 @@ from ._util import (
     get_sql_capabilities_operations,
     get_sql_databases_operations,
     get_sql_database_blob_auditing_policies_operations,
+    get_sql_server_blob_auditing_policies_operations,
     get_sql_database_long_term_retention_backups_operations,
     get_sql_database_long_term_retention_policies_operations,
     get_sql_database_sensitivity_labels_operations,
@@ -41,10 +44,12 @@ from ._util import (
     get_sql_firewall_rules_operations,
     get_sql_instance_pools_operations,
     get_sql_managed_databases_operations,
+    get_sql_managed_database_restore_details_operations,
     get_sql_managed_backup_short_term_retention_policies_operations,
     get_sql_managed_database_long_term_retention_policies_operations,
     get_sql_managed_database_long_term_retention_backups_operations,
     get_sql_managed_instance_azure_ad_administrators_operations,
+    get_sql_managed_instance_azure_ad_only_operations,
     get_sql_managed_instance_encryption_protectors_operations,
     get_sql_managed_instance_keys_operations,
     get_sql_managed_instance_operations_operations,
@@ -52,6 +57,7 @@ from ._util import (
     get_sql_replication_links_operations,
     get_sql_restorable_dropped_databases_operations,
     get_sql_restorable_dropped_managed_databases_operations,
+    get_sql_server_azure_ad_only_operations,
     get_sql_server_connection_policies_operations,
     get_sql_server_dns_aliases_operations,
     get_sql_server_keys_operations,
@@ -60,7 +66,8 @@ from ._util import (
     get_sql_subscription_usages_operations,
     get_sql_virtual_clusters_operations,
     get_sql_virtual_network_rules_operations,
-    get_sql_instance_failover_groups_operations
+    get_sql_instance_failover_groups_operations,
+    get_sql_import_export_operations
 )
 
 from ._validators import (
@@ -100,6 +107,10 @@ def load_command_table(self, _):
         operations_tmpl='azure.mgmt.sql.operations#DatabasesOperations.{}',
         client_factory=get_sql_databases_operations)
 
+    import_export_operations = CliCommandType(
+        operations_tmpl='azure.mgmt.sql.operations#ImportExportOperations.{}',
+        client_factory=get_sql_import_export_operations)
+
     database_lro_transform = LongRunningOperationResultTransform(
         self.cli_ctx, db_transform)
 
@@ -136,9 +147,15 @@ def load_command_table(self, _):
                                  supports_no_wait=True,
                                  transform=database_lro_transform,
                                  table_transformer=db_table_format)
-        g.custom_command('import', 'db_import')
+
         g.custom_command('export', 'db_export')
 
+    with self.command_group('sql db',
+                            import_export_operations,
+                            client_factory=get_sql_import_export_operations) as g:
+
+        g.custom_command('import', 'db_import')
+
     capabilities_operations = CliCommandType(
         operations_tmpl='azure.mgmt.sql.operations#CapabilitiesOperations.{}',
         client_factory=get_sql_capabilities_operations)
@@ -247,9 +264,21 @@ def load_command_table(self, _):
                             database_blob_auditing_policies_operations,
                             client_factory=get_sql_database_blob_auditing_policies_operations) as g:
 
-        g.show_command('show', 'get')
-        g.generic_update_command('update',
-                                 custom_func_name='db_audit_policy_update')
+        g.custom_show_command('show', 'db_audit_policy_show')
+        g.generic_update_command('update', custom_func_name='db_audit_policy_update')
+        g.wait_command('wait')
+
+    server_blob_auditing_policies_operations = CliCommandType(
+        operations_tmpl='azure.mgmt.sql.operations#ServerBlobAuditingPoliciesOperations.{}',
+        client_factory=get_sql_server_blob_auditing_policies_operations)
+
+    with self.command_group('sql server audit-policy',
+                            server_blob_auditing_policies_operations,
+                            client_factory=get_sql_server_blob_auditing_policies_operations) as g:
+
+        g.custom_show_command('show', 'server_audit_policy_show')
+        g.generic_update_command('update', custom_func_name='server_audit_policy_update', supports_no_wait=True)
+        g.wait_command('wait')
 
     database_long_term_retention_policies_operations = CliCommandType(
         operations_tmpl='azure.mgmt.sql.operations#BackupLongTermRetentionPoliciesOperations.{}',
@@ -295,7 +324,7 @@ def load_command_table(self, _):
                             client_factory=get_sql_database_sensitivity_labels_operations) as g:
 
         g.command('list', 'list_current_by_database')
-        g.custom_command('show', 'db_sensitivity_label_show')
+        g.custom_show_command('show', 'db_sensitivity_label_show')
         g.command('delete', 'delete')
         g.custom_command('update', 'db_sensitivity_label_update')
 
@@ -392,7 +421,7 @@ def load_command_table(self, _):
         operations_tmpl='azure.mgmt.sql.operations#FailoverGroupsOperations.{}',
         client_factory=get_sql_failover_groups_operations)
     with self.command_group('sql failover-group', failover_groups_operations, client_factory=get_sql_failover_groups_operations) as g:
-        g.command('show', 'get')
+        g.show_command('show', 'get')
         g.command('list', 'list_by_server')
         g.custom_command('create', 'failover_group_create')
         g.generic_update_command('update', custom_func_name='failover_group_update')
@@ -546,6 +575,18 @@ def load_command_table(self, _):
         c.command('delete', 'delete')
         c.custom_command('set', 'server_dns_alias_set')
 
+    server_aadonly_operations = CliCommandType(
+        operations_tmpl='azure.mgmt.sql.operations#ServerAzureADOnlyAuthenticationsOperations.{}',
+        client_factory=get_sql_server_azure_ad_only_operations)
+
+    with self.command_group('sql server ad-only-auth',
+                            server_aadonly_operations,
+                            client_factory=get_sql_server_azure_ad_only_operations) as g:
+
+        g.custom_command('disable', 'server_aad_only_disable')
+        g.custom_command('enable', 'server_aad_only_enable')
+        g.show_command('get', 'get')
+
     ###############################################
     #                sql managed instance         #
     ###############################################
@@ -557,7 +598,7 @@ def load_command_table(self, _):
     with self.command_group('sql mi op', managed_instance_operations_operations) as g:
 
         g.command('list', 'list_by_managed_instance')
-        g.command('show', 'get')
+        g.show_command('show', 'get')
         g.command('cancel', 'cancel')
 
     managed_instances_operations = CliCommandType(
@@ -568,11 +609,11 @@ def load_command_table(self, _):
                             managed_instances_operations,
                             client_factory=get_sql_managed_instances_operations) as g:
 
-        g.custom_command('create', 'managed_instance_create', supports_no_wait=True)
-        g.command('delete', 'delete', confirmation=True, supports_no_wait=True)
-        g.show_command('show', 'get')
-        g.custom_command('list', 'managed_instance_list')
-        g.generic_update_command('update', custom_func_name='managed_instance_update', supports_no_wait=True)
+        g.custom_command('create', 'managed_instance_create', transform=mi_transform, supports_no_wait=True)
+        g.command('delete', 'delete', transform=mi_transform, confirmation=True, supports_no_wait=True)
+        g.show_command('show', 'get', transform=mi_transform)
+        g.custom_command('list', 'managed_instance_list', transform=mi_list_transform)
+        g.generic_update_command('update', custom_func_name='managed_instance_update', transform=mi_transform, supports_no_wait=True)
         g.command('failover', 'failover', supports_no_wait=True)
 
     managed_instance_keys_operations = CliCommandType(
@@ -612,6 +653,18 @@ def load_command_table(self, _):
         g.custom_command('delete', 'mi_ad_admin_delete')
         g.custom_command('update', 'mi_ad_admin_set')
 
+    managed_instance_aadonly_operations = CliCommandType(
+        operations_tmpl='azure.mgmt.sql.operations#ManagedInstanceAzureADOnlyAuthenticationsOperations.{}',
+        client_factory=get_sql_managed_instance_azure_ad_only_operations)
+
+    with self.command_group('sql mi ad-only-auth',
+                            managed_instance_aadonly_operations,
+                            client_factory=get_sql_managed_instance_azure_ad_only_operations) as g:
+
+        g.custom_command('disable', 'mi_aad_only_disable')
+        g.custom_command('enable', 'mi_aad_only_enable')
+        g.show_command('get', 'get')
+
     ###############################################
     #                sql managed db               #
     ###############################################
@@ -643,7 +696,7 @@ def load_command_table(self, _):
             'update_short_term_retention_mi',
             supports_no_wait=True,
             is_preview=True)
-        g.custom_command('show', 'get_short_term_retention_mi', is_preview=True)
+        g.custom_show_command('show', 'get_short_term_retention_mi', is_preview=True)
 
     managed_database_long_term_retention_policies_operations = CliCommandType(
         operations_tmpl='azure.mgmt.sql.operations#ManagedInstanceLongTermRetentionPoliciesOperations.{}',
@@ -663,7 +716,7 @@ def load_command_table(self, _):
     with self.command_group('sql midb ltr-backup',
                             managed_database_long_term_retention_backups_operations,
                             client_factory=get_sql_managed_database_long_term_retention_backups_operations) as g:
-        g.custom_command('show', 'get_long_term_retention_mi_backup', is_preview=True)
+        g.custom_show_command('show', 'get_long_term_retention_mi_backup', is_preview=True)
         g.custom_command(
             'list',
             'list_long_term_retention_mi_backups', is_preview=True)
@@ -679,6 +732,24 @@ def load_command_table(self, _):
             is_preview=True)
         g.wait_command('wait')
 
+    with self.command_group('sql midb log-replay',
+                            managed_databases_operations,
+                            client_factory=get_sql_managed_databases_operations) as g:
+        g.custom_command('start', 'managed_db_log_replay_start', supports_no_wait=True)
+        g.command('stop', 'delete', confirmation=True, supports_no_wait=True)
+        g.command('complete', 'complete_restore')
+        g.wait_command('wait')
+
+    managed_database_restore_details_operations = CliCommandType(
+        operations_tmpl='azure.mgmt.sql.operations#ManagedDatabaseRestoreDetailsOperations.{}',
+        client_factory=get_sql_managed_database_restore_details_operations)
+
+    with self.command_group('sql midb log-replay',
+                            managed_database_restore_details_operations,
+                            client_factory=get_sql_managed_database_restore_details_operations) as g:
+
+        g.show_command('show', 'get')
+
     ###############################################
     #                sql virtual cluster         #
     ###############################################
@@ -703,7 +774,7 @@ def load_command_table(self, _):
         operations_tmpl='azure.mgmt.sql.operations#InstanceFailoverGroupsOperations.{}',
         client_factory=get_sql_instance_failover_groups_operations)
     with self.command_group('sql instance-failover-group', instance_failover_groups_operations, client_factory=get_sql_instance_failover_groups_operations) as g:
-        g.command('show', 'get')
+        g.show_command('show', 'get')
         g.custom_command('create', 'instance_failover_group_create')
         g.generic_update_command('update', custom_func_name='instance_failover_group_update')
         g.command('delete', 'delete')
