@@ -3,7 +3,8 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from azure.cli.core.commands.client_factory import get_mgmt_service_client, get_data_service_client
+from azure.cli.core.commands.client_factory import get_mgmt_service_client, get_data_service_client, \
+    _prepare_client_kwargs_track2
 from azure.cli.core.profiles import ResourceType, get_sdk
 
 from azure.cli.command_modules.storage.sdkutil import get_table_data_type
@@ -196,6 +197,7 @@ def get_account_url(cli_ctx, account_name, service):
 
 def cf_blob_service(cli_ctx, kwargs):
     from knack.util import CLIError
+    client_kwargs = _prepare_client_kwargs_track2(cli_ctx)
     t_blob_service = get_sdk(cli_ctx, ResourceType.DATA_STORAGE_BLOB,
                              '_blob_service_client#BlobServiceClient')
     connection_string = kwargs.pop('connection_string', None)
@@ -203,9 +205,10 @@ def cf_blob_service(cli_ctx, kwargs):
     account_key = kwargs.pop('account_key', None)
     token_credential = kwargs.pop('token_credential', None)
     sas_token = kwargs.pop('sas_token', None)
+
     if connection_string:
         try:
-            return t_blob_service.from_connection_string(conn_str=connection_string)
+            return t_blob_service.from_connection_string(conn_str=connection_string, **client_kwargs)
         except ValueError as err:
             from azure.cli.core.azclierror import InvalidArgumentValueError
             raise InvalidArgumentValueError('Invalid connection string: {}, err detail: {}'
@@ -217,7 +220,7 @@ def cf_blob_service(cli_ctx, kwargs):
     credential = account_key or sas_token or token_credential
 
     if account_url and credential:
-        return t_blob_service(account_url=account_url, credential=credential)
+        return t_blob_service(account_url=account_url, credential=credential, **client_kwargs)
     raise CLIError("Please provide valid connection string, or account name with account key, "
                    "sas token or login auth mode.")
 
@@ -240,6 +243,7 @@ def cf_container_client(cli_ctx, kwargs):
 
 
 def cf_adls_service(cli_ctx, kwargs):
+    client_kwargs = _prepare_client_kwargs_track2(cli_ctx)
     t_adls_service = get_sdk(cli_ctx, ResourceType.DATA_STORAGE_FILEDATALAKE,
                              '_data_lake_service_client#DataLakeServiceClient')
     connection_string = kwargs.pop('connection_string', None)
@@ -247,14 +251,15 @@ def cf_adls_service(cli_ctx, kwargs):
     account_key = kwargs.pop('account_key', None)
     token_credential = kwargs.pop('token_credential', None)
     sas_token = kwargs.pop('sas_token', None)
+
     if connection_string:
-        return t_adls_service.from_connection_string(conn_str=connection_string)
+        return t_adls_service.from_connection_string(conn_str=connection_string, **client_kwargs)
 
     account_url = get_account_url(cli_ctx, account_name=account_name, service='dfs')
     credential = account_key or sas_token or token_credential
 
     if account_url and credential:
-        return t_adls_service(account_url=account_url, credential=credential)
+        return t_adls_service(account_url=account_url, credential=credential, **client_kwargs)
     return None
 
 
@@ -277,20 +282,22 @@ def cf_or_policy(cli_ctx, _):
 
 def cf_queue_service(cli_ctx, kwargs):
     from knack.util import CLIError
+    client_kwargs = _prepare_client_kwargs_track2(cli_ctx)
     t_queue_service = get_sdk(cli_ctx, ResourceType.DATA_STORAGE_QUEUE, '_queue_service_client#QueueServiceClient')
     connection_string = kwargs.pop('connection_string', None)
     account_name = kwargs.pop('account_name', None)
     account_key = kwargs.pop('account_key', None)
     token_credential = kwargs.pop('token_credential', None)
     sas_token = kwargs.pop('sas_token', None)
+
     if connection_string:
-        return t_queue_service.from_connection_string(conn_str=connection_string)
+        return t_queue_service.from_connection_string(conn_str=connection_string, **client_kwargs)
 
     account_url = get_account_url(cli_ctx, account_name=account_name, service='queue')
     credential = account_key or sas_token or token_credential
 
     if account_url and credential:
-        return t_queue_service(account_url=account_url, credential=credential)
+        return t_queue_service(account_url=account_url, credential=credential, **client_kwargs)
     raise CLIError("Please provide valid connection string, or account name with account key, "
                    "sas token or login auth mode.")
 
