@@ -11,7 +11,9 @@ def file_related_exception_handler(ex):
         raise FileOperationError(ex,
                                  recommendation='Please make sure you have enough permissions on the file/directory.')
     if isinstance(ex, IsADirectoryError):
-        raise FileOperationError(ex, recommendation='File is excepted, not a directory.')
+        raise FileOperationError(ex, recommendation='File is expected, not a directory.')
+    if isinstance(ex, NotADirectoryError):
+        raise FileOperationError(ex, recommendation='Directory is expected, not a file.')
     import sys
     from six import reraise
     reraise(*sys.exc_info())
