@@ -117,7 +117,9 @@ class StorageBatchOperationScenarios(StorageScenarioMixin, LiveScenarioTest):
     @StorageTestFilesPreparer()
     def test_storage_file_batch_download_scenarios(self, test_dir, storage_account_info):
         src_share = self.create_share(storage_account_info)
-
+        # Prepare files
+        snapshot = self.storage_cmd('storage share snapshot -n {} ',
+                                    storage_account_info, src_share).get_output_in_json()["snapshot"]
         self.storage_cmd('storage file upload-batch -s "{}" -d {} --max-connections 3', storage_account_info,
                          test_dir, src_share)
 
@@ -146,6 +148,25 @@ class StorageBatchOperationScenarios(StorageScenarioMixin, LiveScenarioTest):
                          src_share, local_folder)
         self.assertEqual(0, sum(len(f) for r, d, f in os.walk(local_folder)))
 
+        # download with snapshot
+        local_folder = self.create_temp_dir()
+        self.storage_cmd('storage file download-batch -s {} -d "{}" --snapshot {}', storage_account_info,
+                         src_share, local_folder, snapshot)
+        self.assertEqual(0, sum(len(f) for r, d, f in os.walk(local_folder)))
+
+        snapshot = self.storage_cmd('storage share snapshot -n {} ',
+                                    storage_account_info, src_share).get_output_in_json()["snapshot"]
+        self.storage_cmd('storage file download-batch -s {} -d "{}" --snapshot {}', storage_account_info,
+                         src_share, local_folder, snapshot)
+        self.assertEqual(41, sum(len(f) for r, d, f in os.walk(local_folder)))
+
+        local_folder = self.create_temp_dir()
+        share_url = self.storage_cmd('storage file url -s {} -p \'\' -otsv', storage_account_info,
+                                     src_share).output.strip()[:-1]
+        self.storage_cmd('storage file download-batch -s {} -d "{}" --pattern apple/* --snapshot {} ',
+                         storage_account_info, share_url, local_folder, snapshot)
+        self.assertEqual(10, sum(len(f) for r, d, f in os.walk(local_folder)))
+
     @ResourceGroupPreparer()
     @StorageAccountPreparer()
     @StorageTestFilesPreparer()
