@@ -87,7 +87,7 @@ def glob_files_locally(folder_path, pattern):
                 yield (full_path, full_path[len_folder_path:])
 
 
-def glob_files_remotely(cmd, client, share_name, pattern):
+def glob_files_remotely(cmd, client, share_name, pattern, snapshot=None):
     """glob the files in remote file share based on the given pattern"""
     from collections import deque
     t_dir, t_file = cmd.get_models('file.models#Directory', 'file.models#File')
@@ -95,7 +95,7 @@ def glob_files_remotely(cmd, client, share_name, pattern):
     queue = deque([""])
     while queue:
         current_dir = queue.pop()
-        for f in client.list_directories_and_files(share_name, current_dir):
+        for f in client.list_directories_and_files(share_name, current_dir, snapshot=snapshot):
             if isinstance(f, t_file):
                 if not pattern or _match_path(os.path.join(current_dir, f.name), pattern):
                     yield current_dir, f.name
