@@ -14,3 +14,6 @@ def load_command_table(self, _):
 
     with self.command_group('') as g:
         g.custom_command('upgrade', 'upgrade_version', is_preview=True)
+
+    with self.command_group('demo', deprecate_info=g.deprecate(hide=True)) as g:
+        g.custom_command('style', 'demo_style')
